==> examples-4.7.5-src.tar.gz: openejb-examples-4.7.5/deltaspike-fullstack/src/main/java/org/superbiz/deltaspike/domain/Feedback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.superbiz.deltaspike.domain;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.OneToMany;
import java.util.ArrayList;
import java.util.List;

@Entity
public class Feedback extends AbstractDomainObject
{
    private static final long serialVersionUID = -431924785266663236L;

    @Column(nullable = false, length = 32)
    private String topic;

    @Column(length = 128)
    private String description;

    @OneToMany(mappedBy = "feedback", cascade = CascadeType.ALL)
    private List<Comment> comments = new ArrayList<Comment>();

    public void addComment(Comment comment)
    {
        comment.setFeedback(this);
        this.comments.add(comment);
    }

    /*
     * generated
     */

    public List<Comment> getComments()
    {
        return comments;
    }

    public String getTopic()
    {
        return topic;
    }

    public String getDescription()
    {
        return description;
    }

    public void setTopic(String topic)
    {
        this.topic = topic;
    }

    public void setDescription(String description)
    {
        this.description = description;
    }
}

==> examples-7.1.4-src.tar.gz: openejb-examples-7.1.4/deltaspike-fullstack/src/main/java/org/superbiz/deltaspike/domain/Feedback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.superbiz.deltaspike.domain;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.OneToMany;
import java.util.ArrayList;
import java.util.List;

@Entity
public class Feedback extends AbstractDomainObject {
    private static final long serialVersionUID = -431924785266663236L;

    @Column(nullable = false, length = 32)
    private String topic;

    @Column(length = 128)
    private String description;

    @OneToMany(mappedBy = "feedback", cascade = CascadeType.ALL)
    private List<Comment> comments = new ArrayList<Comment>();

    public void addComment(Comment comment) {
        comment.setFeedback(this);
        this.comments.add(comment);
    }

    /*
     * generated
     */

    public List<Comment> getComments() {
        return comments;
    }

    public String getTopic() {
        return topic;
    }

    public String getDescription() {
        return description;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public void setDescription(String description) {
        this.description = description;
    }
}
